@@ -285,11 +285,16 @@ class Exception(Interface):
         return output
 
     def to_html(self, event):
+        last_frame = None
+        interface = event.interfaces.get('sentry.interfaces.Stacktrace')
+        if interface is not None and interface.frames:
+            last_frame = interface.frames[-1]
         return render_to_string('sentry/partial/interfaces/exception.html', {
             'event': event,
             'exception_value': self.value,
             'exception_type': self.type,
             'exception_module': self.module,
+            'last_frame': last_frame
         })
 
     def get_search_context(self, event):
@@ -301,8 +306,8 @@ class Exception(Interface):
 class Http(Interface):
     score = 100
 
-    # methods as defined by http://www.w3.org/Protocols/rfc2616/rfc2616-sec9.html
-    METHODS = ('GET', 'POST', 'PUT', 'OPTIONS', 'HEAD', 'DELETE', 'TRACE', 'CONNECT')
+    # methods as defined by http://www.w3.org/Protocols/rfc2616/rfc2616-sec9.html + PATCH
+    METHODS = ('GET', 'POST', 'PUT', 'OPTIONS', 'HEAD', 'DELETE', 'TRACE', 'CONNECT', 'PATCH')
 
     def __init__(self, url, method=None, data=None, query_string=None, cookies=None, headers=None, env=None, **kwargs):
         if data is None:
@@ -311,8 +316,6 @@ class Http(Interface):
         if method:
             method = method.upper()
 
-            assert method in self.METHODS
-
         urlparts = urlparse.urlsplit(url)
 
         if not query_string:
@@ -335,8 +338,8 @@ class Http(Interface):
         # strip them out
         if headers and 'Cookie' in headers:
             cookies = headers.pop('Cookie')
-            if not self.cookies:
-                cookies = self.cookies
+            if cookies:
+                self.cookies = cookies
         self.headers = headers or {}
         self.env = env or {}
 
@@ -430,9 +433,10 @@ class Template(Interface):
         return [self.filename, self.context_line]
 
     def to_string(self, event):
+        context = get_context(self.lineno, self.context_line, self.pre_context, self.post_context)
         result = [
             'Stacktrace (most recent call last):', '',
-            self.get_traceback()
+            self.get_traceback(event, context)
         ]
 
         return '\n'.join(result)
