@@ -13,7 +13,7 @@ import logging
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect, HttpResponse
 
-from sentry.utils import InstanceManager
+from sentry.utils.db import InstanceManager
 from threading import local
 
 
@@ -37,8 +37,16 @@ class Response(object):
 
 
 class PluginManager(InstanceManager):
-    def for_project(self):
+    def all(self):
+        for plugin in super(PluginManager, self).all():
+            if not plugin.is_enabled():
+                continue
+            yield plugin
+
+    def for_project(self, project):
         for plugin in self.all():
+            if not plugin.is_enabled(project):
+                continue
             if not plugin.has_project_conf():
                 continue
             yield plugin
@@ -112,6 +120,15 @@ class IPlugin(local):
 
     All children should allow ``**kwargs`` on all inherited methods.
     """
+    # Generic plugin information
+    title = None
+    slug = None
+    description = None
+    version = None
+    author = None
+    author_url = None
+
+    # Configuration specifics
     conf_key = None
     conf_title = None
 
@@ -121,15 +138,28 @@ class IPlugin(local):
     site_conf_form = None
     site_conf_template = 'sentry/plugins/site_configuration.html'
 
-    title = None
-    slug = None
-    description = None
-
+    # Global enabled state
     enabled = True
 
     def _get_option_key(self, key):
         return '%s:%s' % (self.get_conf_key(), key)
 
+    def is_enabled(self, project=None):
+        """
+        Returns a boolean representing if this plugin is enabled.
+
+        If ``project`` is passed, it will limit the scope to that project.
+
+        >>> plugin.is_enabled()
+        """
+        if not self.enabled:
+            return False
+        if project:
+            project_enabled = self.get_option('enabled', project)
+            if project_enabled is False:
+                return False
+        return True
+
     def get_option(self, key, project=None):
         """
         Returns the value of an option in your plugins keyspace, or ``None`` if
@@ -137,7 +167,7 @@ class IPlugin(local):
 
         If ``project`` is passed, it will limit the scope to that project's keyspace.
 
-        >>> value = get_option('my_option')
+        >>> value = plugin.get_option('my_option')
         """
         from .helpers import get_option
         return get_option(self._get_option_key(key), project)
@@ -148,7 +178,7 @@ class IPlugin(local):
 
         If ``project`` is passed, it will limit the scope to that project's keyspace.
 
-        >>> set_option('my_option', 'http://example.com')
+        >>> plugin.set_option('my_option', 'http://example.com')
         """
         from .helpers import set_option
         return set_option(self._get_option_key(key), value, project)
@@ -159,7 +189,7 @@ class IPlugin(local):
 
         If ``project`` is passed, it will limit the scope to that project's keyspace.
 
-        >>> unset_option('my_option')
+        >>> plugin.unset_option('my_option')
         """
         from .helpers import unset_option
         return unset_option(self._get_option_key(key), project)
@@ -177,7 +207,7 @@ class IPlugin(local):
         Returns a string representing the configuration keyspace prefix for this plugin.
         """
         if not self.conf_key:
-            return self.conf_title.lower().replace(' ', '_')
+            return self.get_conf_title().lower().replace(' ', '_')
         return self.conf_key
 
     def get_conf_title(self):
