@@ -5,7 +5,11 @@ sentry.plugins.sentry_urls
 :copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+import sentry
+
 from django.db.models import Sum
+from django.utils.translation import ugettext_lazy as _
+
 from sentry.plugins import Plugin, register
 
 
@@ -16,8 +20,11 @@ class UrlsPlugin(Plugin):
     * A panel which shows all urls a message was seen on.
     * A sidebar module which shows the urls most actively seen on.
     """
-
-    title = 'URLs'
+    slug = 'urls'
+    title = _('URLs')
+    version = sentry.VERSION
+    author = "Sentry Team"
+    author_url = "https://github.com/dcramer/sentry"
 
     def get_unique_urls(self, group):
         return group.messagefiltervalue_set.filter(key='url')\
