@@ -365,6 +365,9 @@ def configure_project_plugin(request, project, slug):
     except KeyError:
         return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.pk]))
 
+    if not plugin.is_enabled(project):
+        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.pk]))
+
     result = plugins.first('has_perm', request.user, 'configure_project_plugin', project, plugin)
     if result is False and not request.user.is_superuser:
         return HttpResponseRedirect(reverse('sentry'))
@@ -387,3 +390,26 @@ def configure_project_plugin(request, project, slug):
     })
 
     return render_to_response('sentry/projects/plugins/configure.html', context, request)
+
+
+@login_required
+@has_access(MEMBER_OWNER)
+@csrf_protect
+def manage_plugins(request, project):
+    result = plugins.first('has_perm', request.user, 'configure_project_plugin', project)
+    if result is False and not request.user.has_perm('sentry.can_change_project'):
+        return HttpResponseRedirect(reverse('sentry'))
+
+    if request.POST:
+        enabled = set(request.POST.getlist('plugin'))
+        for plugin in plugins.all():
+            plugin.set_option('enabled', plugin.slug in enabled, project)
+        return HttpResponseRedirect(request.path + '?success=1')
+
+    context = csrf(request)
+    context.update({
+        'page': 'plugins',
+        'project': project,
+    })
+
+    return render_to_response('sentry/projects/plugins/list.html', context, request)
